summaryrefslogtreecommitdiffstats
path: root/lib/agent/project-interface.go
diff options
context:
space:
mode:
Diffstat (limited to 'lib/agent/project-interface.go')
-rw-r--r--lib/agent/project-interface.go18
1 files changed, 7 insertions, 11 deletions
diff --git a/lib/agent/project-interface.go b/lib/agent/project-interface.go
index 031e1d9..0a4a17e 100644
--- a/lib/agent/project-interface.go
+++ b/lib/agent/project-interface.go
@@ -18,19 +18,15 @@ const (
StatusSyncing = "Syncing"
)
-type EventCBData map[string]interface{}
-type EventCB func(cfg *ProjectConfig, data *EventCBData)
-
// IPROJECT Project interface
type IPROJECT interface {
- Add(cfg ProjectConfig) (*ProjectConfig, error) // Add a new project
- Delete() error // Delete a project
- GetProject() *ProjectConfig // Get project public configuration
- SetProject(prj ProjectConfig) *ProjectConfig // Set project configuration
- GetServer() *XdsServer // Get XdsServer that holds this project
- GetFullPath(dir string) string // Get project full path
- Sync() error // Force project files synchronization
- IsInSync() (bool, error) // Check if project files are in-sync
+ Add(cfg ProjectConfig) (*ProjectConfig, error) // Add a new project
+ Delete() error // Delete a project
+ GetProject() *ProjectConfig // Get project public configuration
+ UpdateProject(prj ProjectConfig) (*ProjectConfig, error) // Update project configuration
+ GetServer() *XdsServer // Get XdsServer that holds this project
+ Sync() error // Force project files synchronization
+ IsInSync() (bool, error) // Check if project files are in-sync
}
// ProjectConfig is the config for one project